#include <libnautilus-extension/nautilus-extension-types.h>
#include <libnautilus-extension/nautilus-column-provider.h>
#include "nautilus-metadata.h" 

static void columns_provider_iface_init (NautilusColumnProviderIface *iface);
static GList * get_metadata_columns (NautilusColumnProvider *provider);

static GType tpp_type = 0;

static void columns_provider_iface_init (NautilusColumnProviderIface *iface)
{
	iface->get_columns = get_metadata_columns;
}

static GList * get_metadata_columns (NautilusColumnProvider *provider)
{
	GList *columns = NULL;
        
	/* function interface:
         * NautilusColumn* nautilus_column_new(ID, ATTRIBUTE, LABEL, DESCRIPTION);
         */
        
	NautilusColumn * column;
        column = nautilus_column_new(MEDIA_DURATION_ATTRIBUTE, MEDIA_DURATION_ATTRIBUTE, "Duration", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_ARTIST_ATTRIBUTE, MEDIA_ARTIST_ATTRIBUTE, "Artist", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_TITLE_ATTRIBUTE, MEDIA_TITLE_ATTRIBUTE, "Title", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_ALBUM_ATTRIBUTE, MEDIA_ALBUM_ATTRIBUTE, "Album", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_YEAR_ATTRIBUTE, MEDIA_YEAR_ATTRIBUTE, "Year", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_TRACK_NUMBER_ATTRIBUTE, MEDIA_TRACK_NUMBER_ATTRIBUTE, "Track no.", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_AUDIO_BITRATE_ATTRIBUTE, MEDIA_AUDIO_BITRATE_ATTRIBUTE, "Audio Bitrate", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_AUDIO_CODEC_ATTRIBUTE, MEDIA_AUDIO_CODEC_ATTRIBUTE, "Audio Codec", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_AUDIO_SAMPLE_RATE_ATTRIBUTE, MEDIA_AUDIO_SAMPLE_RATE_ATTRIBUTE, "Audio Samplerate", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_AUDIO_CHANNELS_ATTRIBUTE, MEDIA_AUDIO_CHANNELS_ATTRIBUTE, "Audio Channels", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_VIDEO_RESOLUTION_ATTRIBUTE, MEDIA_VIDEO_RESOLUTION_ATTRIBUTE, "Video Resolution", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_VIDEO_CODEC_ATTRIBUTE, MEDIA_VIDEO_CODEC_ATTRIBUTE, "Video Codec", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_VIDEO_FPS_ATTRIBUTE, MEDIA_VIDEO_FPS_ATTRIBUTE, "Video FPS", "Description");
	columns = g_list_prepend(columns, column);
        
        column = nautilus_column_new(MEDIA_VIDEO_BITRATE_ATTRIBUTE, MEDIA_VIDEO_BITRATE_ATTRIBUTE, "Video Bitrate", "Description");
	columns = g_list_prepend(columns, column);
	
	return columns;
}

void metadata_columns_plugin_register_type(GTypeModule  *module)
{	
	const GTypeInfo info = {
		sizeof (GObjectClass),
		(GBaseInitFunc) NULL,
		(GBaseFinalizeFunc) NULL,
		(GClassInitFunc) NULL,
		NULL,
		NULL,
		sizeof (GObject),
		0,
		(GInstanceInitFunc) NULL
	};
	const GInterfaceInfo columns_provider_iface_info = {
		(GInterfaceInitFunc)columns_provider_iface_init,
		NULL,
		NULL
	};

	tpp_type = g_type_module_register_type (module, G_TYPE_OBJECT,
			"MetadataColumnsPlugin",
			&info, 0);
	g_type_module_add_interface (module,
			tpp_type,
			NAUTILUS_TYPE_COLUMN_PROVIDER,
			&columns_provider_iface_info);
}

void nautilus_module_initialize (GTypeModule  *module)
{
/*
	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
*/
	metadata_columns_plugin_register_type(module);
}

void nautilus_module_shutdown   (void)
{	
}

void nautilus_module_list_types (const GType **types, int *num_types)
{
	static GType type_list[1];

	type_list[0] = tpp_type;
	*types = type_list;
	*num_types = G_N_ELEMENTS (type_list);
}

